pub(crate) struct SuppressExpectedRmcpDrainClose;Trait Implementations
Sourceimpl Clone for SuppressExpectedRmcpDrainClose
impl Clone for SuppressExpectedRmcpDrainClose
Sourcefn clone(&self) -> SuppressExpectedRmcpDrainClose
fn clone(&self) -> SuppressExpectedRmcpDrainClose
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SuppressExpectedRmcpDrainClose
Sourceimpl<S> Filter<S> for SuppressExpectedRmcpDrainClosewhere
S: Subscriber,
impl<S> Filter<S> for SuppressExpectedRmcpDrainClosewhere
S: Subscriber,
Sourcefn enabled(&self, _meta: &Metadata<'_>, _cx: &Context<'_, S>) -> bool
fn enabled(&self, _meta: &Metadata<'_>, _cx: &Context<'_, S>) -> bool
Returns
true if this layer is interested in a span or event with the
given Metadata in the current [Context], similarly to
Subscriber::enabled. Read moreSourcefn event_enabled(&self, event: &Event<'_>, _cx: &Context<'_, S>) -> bool
fn event_enabled(&self, event: &Event<'_>, _cx: &Context<'_, S>) -> bool
Called before the filtered [
Layer]'s [on_event], to determine if on_event` should be called. Read morefn callsite_enabled(&self, meta: &'static Metadata<'static>) -> Interest
fn callsite_enabled(&self, meta: &'static Metadata<'static>) -> Interest
fn max_level_hint(&self) -> Option<LevelFilter>
fn max_level_hint(&self) -> Option<LevelFilter>
fn on_new_span(&self, attrs: &Attributes<'_>, id: &Id, ctx: Context<'_, S>)
fn on_new_span(&self, attrs: &Attributes<'_>, id: &Id, ctx: Context<'_, S>)
fn on_enter(&self, id: &Id, ctx: Context<'_, S>)
fn on_enter(&self, id: &Id, ctx: Context<'_, S>)
Notifies this filter that a span with the given ID was entered. Read more