pub struct SubAccPushReq {
pub acc_ids: Vec<u64>,
pub api_key: Option<String>,
}Fields
acc_ids: Vec<u64>api_key: Option<String>Trait Implementations
Sourceimpl Debug for SubAccPushReq
impl Debug for SubAccPushReq
Sourceimpl<'de> Deserialize<'de> for SubAccPushReq
impl<'de> Deserialize<'de> for SubAccPushReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SubAccPushReq
impl JsonSchema for SubAccPushReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SubAccPushReq
impl RefUnwindSafe for SubAccPushReq
impl Send for SubAccPushReq
impl Sync for SubAccPushReq
impl Unpin for SubAccPushReq
impl UnsafeUnpin for SubAccPushReq
impl UnwindSafe for SubAccPushReq