pub struct SubscribeReq {
pub symbols: Vec<String>,
pub sub_types: Vec<i32>,
pub is_first_push: bool,
pub is_reg_push: bool,
}Expand description
v1.4.74 A1 BUG-011 fix: MCP futu_subscribe request body(对称于
UnsubscribeReq)。
Fields
symbols: Vec<String>sub_types: Vec<i32>is_first_push: boolis_reg_push: boolTrait Implementations
Sourceimpl Debug for SubscribeReq
impl Debug for SubscribeReq
Sourceimpl<'de> Deserialize<'de> for SubscribeReq
impl<'de> Deserialize<'de> for SubscribeReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SubscribeReq
impl JsonSchema for SubscribeReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SubscribeReq
impl RefUnwindSafe for SubscribeReq
impl Send for SubscribeReq
impl Sync for SubscribeReq
impl Unpin for SubscribeReq
impl UnsafeUnpin for SubscribeReq
impl UnwindSafe for SubscribeReq