pub struct UnsubAccPushReq {
pub session_id: Option<String>,
pub api_key: Option<String>,
}Expand description
v1.4.58 Phase A: futu_unsub_acc_push request body.
Fields
session_id: Option<String>session_id from previous futu_sub_acc_push response — required.
rmcp 的 Peer
api_key: Option<String>Trait Implementations
Sourceimpl Debug for UnsubAccPushReq
impl Debug for UnsubAccPushReq
Sourceimpl<'de> Deserialize<'de> for UnsubAccPushReq
impl<'de> Deserialize<'de> for UnsubAccPushReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UnsubAccPushReq
impl JsonSchema for UnsubAccPushReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UnsubAccPushReq
impl RefUnwindSafe for UnsubAccPushReq
impl Send for UnsubAccPushReq
impl Sync for UnsubAccPushReq
impl Unpin for UnsubAccPushReq
impl UnsafeUnpin for UnsubAccPushReq
impl UnwindSafe for UnsubAccPushReq