pub struct UnsubscribeReq {
pub symbols: Vec<String>,
pub sub_types: Vec<i32>,
pub unsub_all: bool,
}Fields
symbols: Vec<String>sub_types: Vec<i32>unsub_all: boolTrait Implementations
Sourceimpl Debug for UnsubscribeReq
impl Debug for UnsubscribeReq
Sourceimpl<'de> Deserialize<'de> for UnsubscribeReq
impl<'de> Deserialize<'de> for UnsubscribeReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UnsubscribeReq
impl JsonSchema for UnsubscribeReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UnsubscribeReq
impl RefUnwindSafe for UnsubscribeReq
impl Send for UnsubscribeReq
impl Sync for UnsubscribeReq
impl Unpin for UnsubscribeReq
impl UnsafeUnpin for UnsubscribeReq
impl UnwindSafe for UnsubscribeReq