pub struct OptionExerciseProbabilityReq {
pub symbol: String,
}Fields
symbol: StringTrait Implementations
Sourceimpl Debug for OptionExerciseProbabilityReq
impl Debug for OptionExerciseProbabilityReq
Sourceimpl<'de> Deserialize<'de> for OptionExerciseProbabilityReq
impl<'de> Deserialize<'de> for OptionExerciseProbabilityReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OptionExerciseProbabilityReq
impl JsonSchema for OptionExerciseProbabilityReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OptionExerciseProbabilityReq
impl RefUnwindSafe for OptionExerciseProbabilityReq
impl Send for OptionExerciseProbabilityReq
impl Sync for OptionExerciseProbabilityReq
impl Unpin for OptionExerciseProbabilityReq
impl UnsafeUnpin for OptionExerciseProbabilityReq
impl UnwindSafe for OptionExerciseProbabilityReq