pub struct DerivativeUnusualReq {
pub stock_symbol: String,
pub time_range: Option<i32>,
pub analysis_dimensions: Vec<String>,
pub language_id: Option<i32>,
}Fields
stock_symbol: Stringtime_range: Option<i32>analysis_dimensions: Vec<String>language_id: Option<i32>Trait Implementations
Sourceimpl Debug for DerivativeUnusualReq
impl Debug for DerivativeUnusualReq
Sourceimpl<'de> Deserialize<'de> for DerivativeUnusualReq
impl<'de> Deserialize<'de> for DerivativeUnusualReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DerivativeUnusualReq
impl JsonSchema for DerivativeUnusualReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DerivativeUnusualReq
impl RefUnwindSafe for DerivativeUnusualReq
impl Send for DerivativeUnusualReq
impl Sync for DerivativeUnusualReq
impl Unpin for DerivativeUnusualReq
impl UnsafeUnpin for DerivativeUnusualReq
impl UnwindSafe for DerivativeUnusualReq