pub struct OptionScreenReq {
pub c2s: Value,
}Fields
c2s: ValueTrait Implementations
Sourceimpl Debug for OptionScreenReq
impl Debug for OptionScreenReq
Sourceimpl<'de> Deserialize<'de> for OptionScreenReq
impl<'de> Deserialize<'de> for OptionScreenReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OptionScreenReq
impl JsonSchema for OptionScreenReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OptionScreenReq
impl RefUnwindSafe for OptionScreenReq
impl Send for OptionScreenReq
impl Sync for OptionScreenReq
impl Unpin for OptionScreenReq
impl UnsafeUnpin for OptionScreenReq
impl UnwindSafe for OptionScreenReq