pub struct TechnicalUnusualReq {
pub stock_symbol: String,
pub time_range: Option<i32>,
pub indicator_filters: Vec<String>,
pub language_id: Option<i32>,
}Fields
stock_symbol: Stringtime_range: Option<i32>indicator_filters: Vec<String>language_id: Option<i32>Trait Implementations
Sourceimpl Debug for TechnicalUnusualReq
impl Debug for TechnicalUnusualReq
Sourceimpl<'de> Deserialize<'de> for TechnicalUnusualReq
impl<'de> Deserialize<'de> for TechnicalUnusualReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TechnicalUnusualReq
impl JsonSchema for TechnicalUnusualReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TechnicalUnusualReq
impl RefUnwindSafe for TechnicalUnusualReq
impl Send for TechnicalUnusualReq
impl Sync for TechnicalUnusualReq
impl Unpin for TechnicalUnusualReq
impl UnsafeUnpin for TechnicalUnusualReq
impl UnwindSafe for TechnicalUnusualReq