pub struct CodeChangeReq {
pub symbols: Vec<String>,
}Fields
symbols: Vec<String>Trait Implementations
Sourceimpl Debug for CodeChangeReq
impl Debug for CodeChangeReq
Sourceimpl<'de> Deserialize<'de> for CodeChangeReq
impl<'de> Deserialize<'de> for CodeChangeReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CodeChangeReq
impl JsonSchema for CodeChangeReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CodeChangeReq
impl RefUnwindSafe for CodeChangeReq
impl Send for CodeChangeReq
impl Sync for CodeChangeReq
impl Unpin for CodeChangeReq
impl UnsafeUnpin for CodeChangeReq
impl UnwindSafe for CodeChangeReq