pub struct FutureInfoReq {
pub symbols: Vec<String>,
}Fields
symbols: Vec<String>Trait Implementations
Sourceimpl Debug for FutureInfoReq
impl Debug for FutureInfoReq
Sourceimpl<'de> Deserialize<'de> for FutureInfoReq
impl<'de> Deserialize<'de> for FutureInfoReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FutureInfoReq
impl JsonSchema for FutureInfoReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FutureInfoReq
impl RefUnwindSafe for FutureInfoReq
impl Send for FutureInfoReq
impl Sync for FutureInfoReq
impl Unpin for FutureInfoReq
impl UnsafeUnpin for FutureInfoReq
impl UnwindSafe for FutureInfoReq