pub struct MarketStateReq {
pub symbols: Vec<String>,
}Fields
symbols: Vec<String>Trait Implementations
Sourceimpl Debug for MarketStateReq
impl Debug for MarketStateReq
Sourceimpl<'de> Deserialize<'de> for MarketStateReq
impl<'de> Deserialize<'de> for MarketStateReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MarketStateReq
impl JsonSchema for MarketStateReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MarketStateReq
impl RefUnwindSafe for MarketStateReq
impl Send for MarketStateReq
impl Sync for MarketStateReq
impl Unpin for MarketStateReq
impl UnsafeUnpin for MarketStateReq
impl UnwindSafe for MarketStateReq