pub struct ModifyUserSecurityReq {
pub group_name: String,
pub op: i32,
pub symbols: Vec<String>,
}Fields
group_name: Stringop: i32symbols: Vec<String>Trait Implementations
Sourceimpl Debug for ModifyUserSecurityReq
impl Debug for ModifyUserSecurityReq
Sourceimpl<'de> Deserialize<'de> for ModifyUserSecurityReq
impl<'de> Deserialize<'de> for ModifyUserSecurityReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ModifyUserSecurityReq
impl JsonSchema for ModifyUserSecurityReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ModifyUserSecurityReq
impl RefUnwindSafe for ModifyUserSecurityReq
impl Send for ModifyUserSecurityReq
impl Sync for ModifyUserSecurityReq
impl Unpin for ModifyUserSecurityReq
impl UnsafeUnpin for ModifyUserSecurityReq
impl UnwindSafe for ModifyUserSecurityReq