pub struct OptionChainReq {Show 16 fields
pub owner_symbol: String,
pub begin_time: String,
pub end_time: String,
pub option_type: Option<String>,
pub delta_min: Option<f64>,
pub delta_max: Option<f64>,
pub iv_min: Option<f64>,
pub iv_max: Option<f64>,
pub oi_min: Option<f64>,
pub oi_max: Option<f64>,
pub gamma_min: Option<f64>,
pub gamma_max: Option<f64>,
pub vega_min: Option<f64>,
pub vega_max: Option<f64>,
pub theta_min: Option<f64>,
pub theta_max: Option<f64>,
}Fields
owner_symbol: Stringbegin_time: Stringend_time: Stringoption_type: Option<String>delta_min: Option<f64>delta_max: Option<f64>iv_min: Option<f64>iv_max: Option<f64>oi_min: Option<f64>oi_max: Option<f64>gamma_min: Option<f64>gamma_max: Option<f64>vega_min: Option<f64>vega_max: Option<f64>theta_min: Option<f64>theta_max: Option<f64>Trait Implementations
Sourceimpl Debug for OptionChainReq
impl Debug for OptionChainReq
Sourceimpl<'de> Deserialize<'de> for OptionChainReq
impl<'de> Deserialize<'de> for OptionChainReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OptionChainReq
impl JsonSchema for OptionChainReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OptionChainReq
impl RefUnwindSafe for OptionChainReq
impl Send for OptionChainReq
impl Sync for OptionChainReq
impl Unpin for OptionChainReq
impl UnsafeUnpin for OptionChainReq
impl UnwindSafe for OptionChainReq