pub struct QuoteRightsReq {
pub refresh: Option<bool>,
}Fields
refresh: Option<bool>Trait Implementations
Sourceimpl Debug for QuoteRightsReq
impl Debug for QuoteRightsReq
Sourceimpl<'de> Deserialize<'de> for QuoteRightsReq
impl<'de> Deserialize<'de> for QuoteRightsReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QuoteRightsReq
impl JsonSchema for QuoteRightsReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for QuoteRightsReq
impl RefUnwindSafe for QuoteRightsReq
impl Send for QuoteRightsReq
impl Sync for QuoteRightsReq
impl Unpin for QuoteRightsReq
impl UnsafeUnpin for QuoteRightsReq
impl UnwindSafe for QuoteRightsReq