pub struct SuspendReq {
pub symbols: Vec<String>,
pub begin_time: String,
pub end_time: String,
}Fields
symbols: Vec<String>begin_time: Stringend_time: StringTrait Implementations
Sourceimpl Debug for SuspendReq
impl Debug for SuspendReq
Sourceimpl<'de> Deserialize<'de> for SuspendReq
impl<'de> Deserialize<'de> for SuspendReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SuspendReq
impl JsonSchema for SuspendReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SuspendReq
impl RefUnwindSafe for SuspendReq
impl Send for SuspendReq
impl Sync for SuspendReq
impl Unpin for SuspendReq
impl UnsafeUnpin for SuspendReq
impl UnwindSafe for SuspendReq