pub struct TickerStatisticDetailReq {
pub symbol: String,
pub ticker_type: Option<i32>,
pub ticker_time: Option<u64>,
pub select_num: Option<u32>,
pub data_from: Option<u32>,
pub data_max_count: Option<u32>,
pub stat_type: Option<u32>,
}Expand description
v1.4.106 codex 0500 ζ23-redo: TickerStatistic Detail params (cmd 6366).
配套 futu_get_ticker_statistic (Info, cmd 6365): 先 call Info 拿
ticker_time, 再 call Detail 同 ticker_time 拿该时点的价位分布 list.
Fields
symbol: Stringticker_type: Option<i32>ticker_time: Option<u64>select_num: Option<u32>data_from: Option<u32>data_max_count: Option<u32>stat_type: Option<u32>Trait Implementations
Sourceimpl Debug for TickerStatisticDetailReq
impl Debug for TickerStatisticDetailReq
Sourceimpl<'de> Deserialize<'de> for TickerStatisticDetailReq
impl<'de> Deserialize<'de> for TickerStatisticDetailReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TickerStatisticDetailReq
impl JsonSchema for TickerStatisticDetailReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TickerStatisticDetailReq
impl RefUnwindSafe for TickerStatisticDetailReq
impl Send for TickerStatisticDetailReq
impl Sync for TickerStatisticDetailReq
impl Unpin for TickerStatisticDetailReq
impl UnsafeUnpin for TickerStatisticDetailReq
impl UnwindSafe for TickerStatisticDetailReq