pub struct TickerStatisticReq {
pub symbol: String,
pub ticker_type: Option<i32>,
pub stat_type: Option<u32>,
}Expand description
v1.4.98 T2-3 (mobile-source-audit Phase 2): TickerStatistic params.
Fields
symbol: Stringticker_type: Option<i32>stat_type: Option<u32>Trait Implementations
Sourceimpl Debug for TickerStatisticReq
impl Debug for TickerStatisticReq
Sourceimpl<'de> Deserialize<'de> for TickerStatisticReq
impl<'de> Deserialize<'de> for TickerStatisticReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TickerStatisticReq
impl JsonSchema for TickerStatisticReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TickerStatisticReq
impl RefUnwindSafe for TickerStatisticReq
impl Send for TickerStatisticReq
impl Sync for TickerStatisticReq
impl Unpin for TickerStatisticReq
impl UnsafeUnpin for TickerStatisticReq
impl UnwindSafe for TickerStatisticReq