pub struct UserSecurityGroupReq {
pub group_type: i32,
}Fields
group_type: i32Trait Implementations
Sourceimpl Debug for UserSecurityGroupReq
impl Debug for UserSecurityGroupReq
Sourceimpl<'de> Deserialize<'de> for UserSecurityGroupReq
impl<'de> Deserialize<'de> for UserSecurityGroupReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserSecurityGroupReq
impl JsonSchema for UserSecurityGroupReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UserSecurityGroupReq
impl RefUnwindSafe for UserSecurityGroupReq
impl Send for UserSecurityGroupReq
impl Sync for UserSecurityGroupReq
impl Unpin for UserSecurityGroupReq
impl UnsafeUnpin for UserSecurityGroupReq
impl UnwindSafe for UserSecurityGroupReq