pub struct UserSecurityReq {
pub group_name: String,
}Fields
group_name: StringTrait Implementations
Sourceimpl Debug for UserSecurityReq
impl Debug for UserSecurityReq
Sourceimpl<'de> Deserialize<'de> for UserSecurityReq
impl<'de> Deserialize<'de> for UserSecurityReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserSecurityReq
impl JsonSchema for UserSecurityReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UserSecurityReq
impl RefUnwindSafe for UserSecurityReq
impl Send for UserSecurityReq
impl Sync for UserSecurityReq
impl Unpin for UserSecurityReq
impl UnsafeUnpin for UserSecurityReq
impl UnwindSafe for UserSecurityReq