pub struct ProtoJsonReq {
pub c2s_json: String,
pub api_key: Option<String>,
}Expand description
Official proto C2S JSON wrapper for endpoints whose ergonomic MCP surface is intentionally kept tied to generated protobuf shape.
Fields
c2s_json: Stringapi_key: Option<String>Trait Implementations
Sourceimpl Debug for ProtoJsonReq
impl Debug for ProtoJsonReq
Sourceimpl<'de> Deserialize<'de> for ProtoJsonReq
impl<'de> Deserialize<'de> for ProtoJsonReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProtoJsonReq
impl JsonSchema for ProtoJsonReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProtoJsonReq
impl RefUnwindSafe for ProtoJsonReq
impl Send for ProtoJsonReq
impl Sync for ProtoJsonReq
impl Unpin for ProtoJsonReq
impl UnsafeUnpin for ProtoJsonReq
impl UnwindSafe for ProtoJsonReq