pub struct AccountFlagReq {
pub env: String,
pub acc_id: u64,
pub flag_id: u32,
}Fields
env: Stringacc_id: u64flag_id: u32Trait Implementations
Sourceimpl Debug for AccountFlagReq
impl Debug for AccountFlagReq
Sourceimpl<'de> Deserialize<'de> for AccountFlagReq
impl<'de> Deserialize<'de> for AccountFlagReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AccountFlagReq
impl JsonSchema for AccountFlagReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AccountFlagReq
impl RefUnwindSafe for AccountFlagReq
impl Send for AccountFlagReq
impl Sync for AccountFlagReq
impl Unpin for AccountFlagReq
impl UnsafeUnpin for AccountFlagReq
impl UnwindSafe for AccountFlagReq