pub struct BondAccountReq {
pub env: String,
pub acc_id: u64,
pub market: String,
}Fields
env: Stringacc_id: u64market: StringTrait Implementations
Sourceimpl Debug for BondAccountReq
impl Debug for BondAccountReq
Sourceimpl<'de> Deserialize<'de> for BondAccountReq
impl<'de> Deserialize<'de> for BondAccountReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BondAccountReq
impl JsonSchema for BondAccountReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BondAccountReq
impl RefUnwindSafe for BondAccountReq
impl Send for BondAccountReq
impl Sync for BondAccountReq
impl Unpin for BondAccountReq
impl UnsafeUnpin for BondAccountReq
impl UnwindSafe for BondAccountReq