pub struct CashLogReq {Show 14 fields
pub env: String,
pub acc_id: u64,
pub market: Option<String>,
pub begin_time: Option<u64>,
pub end_time: Option<u64>,
pub biz_group_id: Option<u32>,
pub biz_sub_group_id: Option<u32>,
pub in_out: Option<u32>,
pub keyword: Option<String>,
pub symbol: Option<String>,
pub stock_id: Option<u64>,
pub log_id: Option<String>,
pub max_cnt: Option<u32>,
pub currency: Option<String>,
}Fields
env: Stringacc_id: u64market: Option<String>begin_time: Option<u64>end_time: Option<u64>biz_group_id: Option<u32>biz_sub_group_id: Option<u32>in_out: Option<u32>keyword: Option<String>symbol: Option<String>stock_id: Option<u64>log_id: Option<String>max_cnt: Option<u32>currency: Option<String>Trait Implementations
Sourceimpl Debug for CashLogReq
impl Debug for CashLogReq
Sourceimpl<'de> Deserialize<'de> for CashLogReq
impl<'de> Deserialize<'de> for CashLogReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CashLogReq
impl JsonSchema for CashLogReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CashLogReq
impl RefUnwindSafe for CashLogReq
impl Send for CashLogReq
impl Sync for CashLogReq
impl Unpin for CashLogReq
impl UnsafeUnpin for CashLogReq
impl UnwindSafe for CashLogReq