pub struct HistoryQueryReq {
pub market: String,
pub acc_id: u64,
pub env: String,
pub code_list: Vec<String>,
pub begin_time: Option<String>,
pub end_time: Option<String>,
}Fields
market: Stringacc_id: u64env: Stringcode_list: Vec<String>begin_time: Option<String>end_time: Option<String>Trait Implementations
Sourceimpl Debug for HistoryQueryReq
impl Debug for HistoryQueryReq
Sourceimpl<'de> Deserialize<'de> for HistoryQueryReq
impl<'de> Deserialize<'de> for HistoryQueryReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HistoryQueryReq
impl JsonSchema for HistoryQueryReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HistoryQueryReq
impl RefUnwindSafe for HistoryQueryReq
impl Send for HistoryQueryReq
impl Sync for HistoryQueryReq
impl Unpin for HistoryQueryReq
impl UnsafeUnpin for HistoryQueryReq
impl UnwindSafe for HistoryQueryReq