pub struct OrderFeeReq {
pub market: String,
pub acc_id: u64,
pub env: String,
pub order_id_ex_list: Vec<String>,
}Fields
market: Stringacc_id: u64env: Stringorder_id_ex_list: Vec<String>Trait Implementations
Sourceimpl Debug for OrderFeeReq
impl Debug for OrderFeeReq
Sourceimpl<'de> Deserialize<'de> for OrderFeeReq
impl<'de> Deserialize<'de> for OrderFeeReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OrderFeeReq
impl JsonSchema for OrderFeeReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OrderFeeReq
impl RefUnwindSafe for OrderFeeReq
impl Send for OrderFeeReq
impl Sync for OrderFeeReq
impl Unpin for OrderFeeReq
impl UnsafeUnpin for OrderFeeReq
impl UnwindSafe for OrderFeeReq