pub struct PlaceOrderReq {Show 15 fields
pub market: String,
pub acc_id: Option<u64>,
pub card_num: Option<String>,
pub env: String,
pub side: String,
pub order_type: String,
pub code: String,
pub qty: f64,
pub price: Option<f64>,
pub api_key: Option<String>,
pub idempotency_key: Option<String>,
pub stop_price: Option<f64>,
pub trail_type: Option<i32>,
pub trail_value: Option<f64>,
pub trail_spread: Option<f64>,
}Fields
market: Stringacc_id: Option<u64>card_num: Option<String>env: Stringside: Stringorder_type: Stringcode: Stringqty: f64price: Option<f64>api_key: Option<String>idempotency_key: Option<String>stop_price: Option<f64>trail_type: Option<i32>trail_value: Option<f64>trail_spread: Option<f64>Trait Implementations
Sourceimpl Debug for PlaceOrderReq
impl Debug for PlaceOrderReq
Sourceimpl<'de> Deserialize<'de> for PlaceOrderReq
impl<'de> Deserialize<'de> for PlaceOrderReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PlaceOrderReq
impl JsonSchema for PlaceOrderReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PlaceOrderReq
impl RefUnwindSafe for PlaceOrderReq
impl Send for PlaceOrderReq
impl Sync for PlaceOrderReq
impl Unpin for PlaceOrderReq
impl UnsafeUnpin for PlaceOrderReq
impl UnwindSafe for PlaceOrderReq