pub struct KLineReq {
pub symbol: String,
pub kl_type: String,
pub count: Option<i32>,
pub begin: Option<String>,
pub end: Option<String>,
}Fields
symbol: Stringkl_type: Stringcount: Option<i32>begin: Option<String>end: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for KLineReq
impl<'de> Deserialize<'de> for KLineReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KLineReq
impl JsonSchema for KLineReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for KLineReq
impl RefUnwindSafe for KLineReq
impl Send for KLineReq
impl Sync for KLineReq
impl Unpin for KLineReq
impl UnwindSafe for KLineReq