pub struct ModifyOrderReq {
pub market: String,
pub acc_id: u64,
pub env: String,
pub order_id: u64,
pub op: String,
pub qty: Option<f64>,
pub price: Option<f64>,
pub api_key: Option<String>,
}Fields
market: Stringacc_id: u64env: Stringorder_id: u64op: Stringqty: Option<f64>price: Option<f64>api_key: Option<String>Trait Implementations
Sourceimpl Debug for ModifyOrderReq
impl Debug for ModifyOrderReq
Sourceimpl<'de> Deserialize<'de> for ModifyOrderReq
impl<'de> Deserialize<'de> for ModifyOrderReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ModifyOrderReq
impl JsonSchema for ModifyOrderReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ModifyOrderReq
impl RefUnwindSafe for ModifyOrderReq
impl Send for ModifyOrderReq
impl Sync for ModifyOrderReq
impl Unpin for ModifyOrderReq
impl UnwindSafe for ModifyOrderReq