pub struct PlaceOrderReq {
pub market: String,
pub acc_id: u64,
pub env: String,
pub side: String,
pub order_type: String,
pub code: String,
pub qty: f64,
pub price: Option<f64>,
pub api_key: Option<String>,
}Fields
market: Stringacc_id: u64env: Stringside: Stringorder_type: Stringcode: Stringqty: f64price: Option<f64>api_key: Option<String>Trait Implementations
Sourceimpl Debug for PlaceOrderReq
impl Debug for PlaceOrderReq
Sourceimpl<'de> Deserialize<'de> for PlaceOrderReq
impl<'de> Deserialize<'de> for PlaceOrderReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PlaceOrderReq
impl JsonSchema for PlaceOrderReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PlaceOrderReq
impl RefUnwindSafe for PlaceOrderReq
impl Send for PlaceOrderReq
impl Sync for PlaceOrderReq
impl Unpin for PlaceOrderReq
impl UnwindSafe for PlaceOrderReq