pub struct PlateListReq {
pub market: String,
pub plate_set: String,
}Fields
market: Stringplate_set: StringTrait Implementations
Sourceimpl Debug for PlateListReq
impl Debug for PlateListReq
Sourceimpl<'de> Deserialize<'de> for PlateListReq
impl<'de> Deserialize<'de> for PlateListReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PlateListReq
impl JsonSchema for PlateListReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PlateListReq
impl RefUnwindSafe for PlateListReq
impl Send for PlateListReq
impl Sync for PlateListReq
impl Unpin for PlateListReq
impl UnwindSafe for PlateListReq