pub struct SymbolListReq {
pub symbols: Vec<String>,
}Fields
symbols: Vec<String>Trait Implementations
Sourceimpl Debug for SymbolListReq
impl Debug for SymbolListReq
Sourceimpl<'de> Deserialize<'de> for SymbolListReq
impl<'de> Deserialize<'de> for SymbolListReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SymbolListReq
impl JsonSchema for SymbolListReq
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SymbolListReq
impl RefUnwindSafe for SymbolListReq
impl Send for SymbolListReq
impl Sync for SymbolListReq
impl Unpin for SymbolListReq
impl UnwindSafe for SymbolListReq