pub(crate) fn outcome_key_id_from_snapshot<'a>(
caller_key_rec: Option<&'a Arc<KeyRecord>>,
authed_key_at_precheck: Option<&'a Arc<KeyRecord>>,
) -> Option<&'a str>Expand description
Compute the audit key id from the same snapshot used by the write precheck.
This prevents SIGHUP reload between daemon dispatch and audit emission from
re-attributing an outcome to the startup key or <none>.